Этот коммит содержится в:
Aditya Atluri
2016-03-30 06:08:50 -05:00
родитель da1d9caf6b
Коммит 496da0aabd
10 изменённых файлов: 64 добавлений и 97 удалений
+4 -4
Просмотреть файл
@@ -53,14 +53,14 @@ __device__ __host__ float PlusOne(float x)
__global__ void MyKernel (const hipLaunchParm lp, const float *a, const float *b, float *c, unsigned N)
{
KERNELBEGIN;
//KERNELBEGIN;
unsigned gid = hipThreadIdx_x;
if (gid < N) {
c[gid] = a[gid] + PlusOne(b[gid]);
}
KERNELEND;
//KERNELEND;
}
@@ -82,7 +82,7 @@ vectorADD(const hipLaunchParm lp,
T *C_d,
size_t N)
{
KERNELBEGIN;
// KERNELBEGIN;
int ws = warpSize;
@@ -119,7 +119,7 @@ vectorADD(const hipLaunchParm lp,
C_d[i] = A_d[i] + B_d[i];
}
KERNELEND;
// KERNELEND;
}